<?php
/**
 * Plugin Name: Advanced Business Hours
 * Plugin URI: https://codecanyon.net/user/mrbeaver
 * Description: This plugin creates an advanced widget that can be used to display business hours.
 * Version: 1.6.1
 * Author: 20script
 * Text Domain: 20script
 * Domain Path: /languages
 * Author URI: http://www.20script.ir
 * License: Please see the license folder
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Advanced_Business_Hours {
	/**
	 * Constructor.
	 */
	public function __construct() {
		// Set the constants.
		add_action( 'plugins_loaded', array( $this, 'constants' ), 1 );
		// Load the necessary files.
		add_action( 'plugins_loaded', array( $this, 'includes' ), 4 );
		// Internationalize the text strings
		add_action( 'plugins_loaded', array( $this, 'languages' ), 2 );
		// Loads the admin styles and scripts.
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );
		// Load the front end styles and scripts.
		add_action( 'wp_enqueue_scripts', array( $this, 'front_scripts' ) );
		// Register the widget.
		add_action( 'widgets_init', array( $this, 'widget' ) );
		// Add documentation & widget links
		add_filter( 'plugin_action_links', array( $this, 'add_links' ), 10, 5 );

	}

	/**
	 * Set constants
	 *
	 * @since 1.6.0
	 */
	public function constants() {
		define( 'ADV_BUSINESS_HOURS_VERSION', '1.6.1' );
		define( 'ADV_BUSINESS_HOURS_DIR', plugin_dir_path( __FILE__ ) );
		define( 'ADV_BUSINESS_HOURS_URL', plugin_dir_url( __FILE__ ) );
	}

	/**
	 * Include necessary files
	 *
	 * @since 1.6.0
	 */
	public function includes() {
		require_once ADV_BUSINESS_HOURS_DIR . 'includes/shortcodes.php';
		require_once ADV_BUSINESS_HOURS_DIR . 'includes/functions.php';
		require_once ADV_BUSINESS_HOURS_DIR . 'includes/widget.php';
	}

	/**
	 * Internationalize the text
	 *
	 * @since 1.6.0
	 */
	public function languages() {
		load_plugin_textdomain( 'adv-business-hours', false, basename( dirname( __FILE__ ) ) . '/languages/' );
	}

	/**
	 * Load custom styles and js in the admin area
	 *
	 * @since 1.6.0
	 */
	public function admin_scripts() {
		wp_register_style( 'adv_business_hours_admin_style', plugins_url( '/css/abh-admin.css', __FILE__ ) );
		wp_enqueue_style( 'adv_business_hours_admin_style' );
		wp_enqueue_style( 'wp-color-picker' );
		wp_enqueue_script( 'adv-business-hours-color-picker', plugins_url( '/js/color-picker.js', __FILE__ ), array( 'wp-color-picker' ), false, true );
		wp_enqueue_media();
		wp_enqueue_script( 'adv-business-hours-media-upload', plugins_url( '/js/media-upload.js', __FILE__ ) );
		wp_enqueue_script( 'adv-business-hours-admin-js', plugins_url( '/js/abh-admin.js', __FILE__ ) );
	}

	/**
	 * Load the main style for frontend
	 *
	 * @since 1.6.0
	 */
	public function front_scripts() {
		wp_register_style( 'adv-business-hours-main-style', plugins_url( '/css/abh-style.css', __FILE__ ) );
		wp_register_style( 'adv-business-hours-custom-style', plugins_url( '/css/abh-custom-style.css', __FILE__ ) );
		wp_enqueue_style( 'adv-business-hours-main-style' );
		wp_enqueue_style( 'adv-business-hours-custom-style' );
		// ajax scripts
		wp_enqueue_script( 'abh-ajax-script', plugins_url( '/js/abh-ajax.js', __FILE__ ), array( 'jquery' ) );
		wp_localize_script( 'abh-ajax-script', 'abh_ajax', array(
			'ajax_url'   => admin_url( 'admin-ajax.php' ),
			'ajax_nonce' => wp_create_nonce( 'abh-ajax-nonce' ),
		) );
	}

	/**
	 * Register the widget
	 *
	 * @since 1.6.0
	 */
	public function widget() {
		register_widget( 'Adv_Business_Hours_Widget' );
	}

	/**
	 *
	 * Link to documentation in the admin area
	 *
	 * @param $links
	 *
	 * @return array
	 * @since 1.0.0
	 */
	public function add_links( $actions, $plugin_file ) {
		static $plugin;

		if ( ! isset( $plugin ) ) {
			$plugin = plugin_basename( __FILE__ );
		}
		if ( $plugin == $plugin_file ) {

			$settings  = array( 'widgets' => '<a href="' . esc_url( get_admin_url( null, 'widgets.php' ) ) . '">Widgets</a>' );
			$site_link = array( 'support' => '<a href="https://help.dolatabadi.ca/" target="_blank">Help Center</a>' );

			$actions = array_merge( $settings, $actions );
			$actions = array_merge( $site_link, $actions );

		}

		return $actions;
	}


}

new Advanced_Business_Hours();